# WDL-AID
Generate documentation for the inputs of WDL workflows, based on the
parameter_meta information defined in the WDL file.

## documentation
You can find documentation on how to use WDL-AID here:
https://wdl-aid.readthedocs.io

## Bugs and feature requests
Please report any bugs, issues or pull requests on the
[github issue tracker](https://github.com/biowdl/wdl-aid/issues).
